ETE’s Reference Guide — ETE Toolkit - analysis and visualization of trees

# ETE’s Reference Guide

Current modules:

- Master Tree class
- Treeview module
  - TreeStyle
  - NodeStyle
  - Faces
  - Color names
- PhyloTree class
- Clustering module
- Nexml module
  - Nexml classes linked to ETE
  - Generic Nexml classes
- Phyloxml Module
  - Phyloxml classes linked to ETE
  - Generic Phyloxml classes
- Seqgroup class
- WebTreeApplication object
- EvolTree class
- NCBITaxa class